@@ -138,6 +138,7 @@ ETHEREUM_NETWORK = "eth"
 BINANCE_NETWORK = "bsc"
 POLYGON_NETWORK = "polygon"
 ARBITRUM_NETWORK = "arbitrum"
+DEVELOPMENT_NETWORK = "development"
 
 SUPPORTED_NETWORKS = [ETHEREUM_NETWORK, BINANCE_NETWORK, POLYGON_NETWORK, ARBITRUM_NETWORK]
 
@@ -151,3 +152,32 @@ BSC_STATIC_PRICE = Wei("10 gwei")
 HISTORICAL_MAINNET_ELASTIC_URL = "https://api.anyblock.tools/ethereum/ethereum/mainnet/es/"
 
 NUMBER_OF_BINS = 60  # number of bins for histogram
+
+TARGET_TOKENS = [
+    "0x3472A5A71965499acd81997a54BBA8D852C6E53d",
+    "0x19D97D8fA813EE2f51aD4B4e04EA08bAf4DFfC28",
+    "0xAf5A1DECfa95BAF63E0084a35c62592B774A2A87",
+    "0xcD7989894bc033581532D2cd88Da5db0A4b12859",
+    "0xe86204c4eddd2f70ee00ead6805f917671f56c52",
+    "0x075b1bb99792c9E1041bA13afEf80C91a1e70fB3",
+    "0xd04c48A53c111300aD41190D63681ed3dAd998eC",
+    "0x49849C98ae39Fff122806C06791Fa73784FB3675",
+    "0x6dEf55d2e18486B9dDfaA075bc4e4EE0B28c1545",
+    "0x64eda51d3Ad40D56b9dFc5554E06F94e1Dd786Fd",
+    "0xb9D076fDe463dbc9f915E5392F807315Bf940334",
+    "0xb19059ebb43466C323583928285a49f558E572Fd",
+    "0xDE5331AC4B3630f94853Ff322B66407e0D6331E8",
+    "0x2fE94ea3d5d4a175184081439753DE15AeF9d614",
+    "0x410e3E86ef427e30B9235497143881f717d93c2A",
+    "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
+    "0x110492b31c59716AC47337E616804E3E3AdC0b4a",
+    "0xCEfF51756c56CeFFCA006cD410B03FFC46dd3a58",
+    "0x758A43EE2BFf8230eeb784879CdcFF4828F2544D",
+    "0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48",
+    "0x798D1bE841a82a273720CE31c822C61a67a601C3",
+    "0xeb4c2781e4eba804ce9a9803c67d0893436bb27d",
+    "0xcA3d75aC011BF5aD07a98d02f18225F9bD9A6BDF",
+    "0x4e3fbd56cd56c3e72c1403e103b45db9da5b9d2b",
+    "0x62b9c7356a2dc64a1969e19c23e4f579f9810aa7",
+    "0xFbdCA68601f835b27790D98bbb8eC7f05FDEaA9B",
+]
